package com.muyu.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.domain.AssetAuthorization;
import com.muyu.server.mapper.AssetAuthorizationMapper;
import com.muyu.server.mapper.DataRunNameMapper;
import com.muyu.server.service.AssetAuthorizationService;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：yang
 * @Package：com.muyu.server.service.impl
 * @Project：cloud-property
 * @name：AssetAuthorizationServiceImpl
 * @Date：2024/9/4 21:18
 */
@Service
@AllArgsConstructor
public class AssetAuthorizationServiceImpl
        extends ServiceImpl<AssetAuthorizationMapper, AssetAuthorization>
        implements AssetAuthorizationService {

    private final AssetAuthorizationMapper assetAuthorizationMapper;
    private final DataRunNameMapper dataRunNameMapper;

    /**
     * 删除用户权限方法
     * @param req 响应参数
     * @return  返回结果
     */
    @Override
    public Long delUserAssetAccredit(AssetAuthorization req) {
        LambdaQueryWrapper<AssetAuthorization> queryWrapper = new LambdaQueryWrapper<>();
        if (null==req.getUserId()) {
            return 0L;
        }
            Long delete = dataRunNameMapper.delUserAssetAccreditDept(Math.toIntExact(req.getUserId()));
            return delete;
    }

    @Override
    public Long delDeptAssetAccredit(AssetAuthorization req) {
        LambdaQueryWrapper<AssetAuthorization> queryWrapper = new LambdaQueryWrapper<>();
        if (null==req.getDeptId()) {
            return 0L;
        }

        Long delete = dataRunNameMapper.delDeptAssetAccredit(Math.toIntExact(req.getDeptId()));
            return delete;
    }

    /**
     * 查询资产赋权用户信息
     * @param req 响应参数
     * @return 返回结果
     */
    @Override
    public List<Long> findUserIdList(AssetAuthorization req) {
        List<Long> userIdList = dataRunNameMapper.findUserIdList(req);
        return userIdList;
    }

    /**
     * 查询资产赋权部门的信息
     * @param req 响应参数
     * @return 返回结果
     */
    @Override
    public List<Long> findDeptIdList(AssetAuthorization req) {
        List<Long> deptIdList = dataRunNameMapper.findDeptIdList(req);
        return deptIdList;
    }
}
