package com.muyu.server.service.impl;

import com.alibaba.druid.pool.DruidDataSource;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.enums.SystemYesNo;
import com.muyu.common.domain.Connect;
import com.muyu.common.domain.DataName;
import com.muyu.server.mapper.ConnectMapper;
import com.muyu.server.service.ConnectService;
import com.muyu.server.service.OrderConnectService;
import com.muyu.server.util.JdbcHelper;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：yang
 * @Package：com.muyu.server.service.impl
 * @Project：cloud-property
 * @name：ConnectReqServiceImpl
 * @Date：2024/8/25 16:15
 */
@Service
@AllArgsConstructor
public class ConnectServiceImpl
        extends ServiceImpl<ConnectMapper, Connect>
        implements ConnectService {

    private final OrderConnectService orderConnectService;
    private final ConnectMapper connectMapper;



    /**
     * 查询配置表
     * @param connect 配置列表请求参数
     * @return 返回试图
     */
    @Override
    public List<Connect> selectConnect(Connect connect) {
        LambdaQueryWrapper<Connect> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(
                StringUtils.isNotEmpty(connect.getAccSourName()),
                Connect::getAccSourName, connect.getAccSourName()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(connect.getDataSourSystemName()),
                Connect::getDataSourSystemName, connect.getDataSourSystemName()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(connect.getDatabaseName()),
                Connect::getDatabaseName, connect.getDatabaseName()
        );
        List<Connect> connects = this.list(queryWrapper);
        return connects.stream()
                .map(connect1 -> Connect.connectBuild(connect1, () ->
                        orderConnectService.selectConnectByAppCodeAndLimit(connect1.getId(),5)
                                        .stream()
                                        .toList()
                ))
                .toList();
    }

    /**
     * 通过ID改变初始化状态 将可以被初始化
     * @param id 响应ID
     * @return 返回结果
     */
    @Override
    public boolean updInitDisable(Integer id) {
        return this.settingStatus(id, SystemYesNo.YES.getCode());
    }

    /**
     * 通过ID改变初始化状态 将不再被初始化
     * @param id 响应ID
     * @return 返回结果
     */
    @Override
    public boolean updInitEnable(Integer id) {
        return this.settingStatus(id, SystemYesNo.YES.getCode());
    }

    /**
     * 测试接口
     * @param connect 响应ID
     * @return 返回结果
     */
    @Override
    public boolean text(Connect connect) {
        try {
            JdbcHelper.getConn(connect);
            return true;
        }catch (Exception e){
            return false;
        }
    }

    /**
     * 查询返回对象
     * @param dataName 响应名称
     * @return
     */
    @Override
    public Connect selectData(String dataName) {
        return connectMapper.selectData(dataName);
    }

    private boolean settingStatus(Integer id, String initialization) {
        return this.updateById(
                Connect.builder()
                        .id(id)
                        .initialization(initialization)
                        .build()
        );
    }
}
