package com.muyu.server.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.domain.req.CoreDataListReq;
import com.muyu.server.mapper.OperateCoreDataMapper;
import com.muyu.server.service.OperateCoreDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * @Author：蓬叁
 * @Package：com.muyu.server.service.impl
 * @Project：cloud-integration
 * @name：OperateCoreDataServiceImpl
 * @Date：2024/8/21 下午10:20
 */
@Service
public class OperateCoreDataServiceImpl
        extends ServiceImpl<OperateCoreDataMapper, CoreDataListReq>
        implements OperateCoreDataService {

    @Autowired private OperateCoreDataMapper operateCoreDataMapper;

    private final ExecutorService executor = Executors.newFixedThreadPool(100);

    /**
     * 使用线程 与 mybatis-plus 进行添加
     * @param coreDataReqList 参数集合
     * @return 添加后结果
     */
    @Override
    public void addCoreData(List<CoreDataListReq> coreDataReqList) {

        int size = 5000;
        int totalBatches = (coreDataReqList.size() + size - 1) / size;

        List<CompletableFuture<?>> futures = new ArrayList<>();

        for (int i = 0; i < totalBatches; i++) {
            int start = i * size;
            int end = Math.min(start + size, coreDataReqList.size());
            List<CoreDataListReq> batchData = coreDataReqList.subList(start, end);

            CompletableFuture<?> future = CompletableFuture.runAsync(() -> {
                saveBatch(batchData);
            }, executor);
            futures.add(future);
        }
        executor.shutdown();
    }
}
