package com.muyu.server.util;

import com.alibaba.druid.pool.DruidDataSource;
import com.muyu.common.domain.Connect;
import com.muyu.common.domain.req.ConnectReq;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Component;

import java.sql.*;

/**
 * @Author：张腾
 * @Package：com.muyu.server.util
 * @Project：cloud-integration
 * @name：BaseDao
 * @Date：2024/8/20 21:45
 */
@Component
@Log4j2
public class JdbcHelper {

    /**
     * 连接池
     * @param connect 连接池对象参数 查询结构
     * @return 返回结果
     */
    public static DruidDataSource getConn( Connect connect) {
        while (0<connect.getMaxWaitTimes()){
            try {
                DruidDataSource druidDataSource = new DruidDataSource();
                String dcp = connect.getDataConnParam();
                druidDataSource.setUrl(new ConnectReq().getUrl()
                        +connect.getIpAddress()+":"+connect.getPort()+
                        "/"+connect.getDatabaseName() +
                        (dcp != null && !dcp.isEmpty()? "?" + dcp : ""));
                druidDataSource.setUsername(connect.getUserName());
                druidDataSource.setPassword(connect.getPassword());
                //"com.mysql.cj.jdbc.Driver"
                druidDataSource.setDriverClassName(new ConnectReq().getDRIVER());
                druidDataSource.setInitialSize(connect.getInitSize());
                druidDataSource.setMaxActive(connect.getMaxNumConn());
                druidDataSource.setMaxWait(connect.getMaxWaitTime());

                return druidDataSource;
            } catch (Exception e) {
                log.error("异常为：{}", String.valueOf(e));
            }
        }

        return null;
    }

    /**
     * 查询服务器上说有数据库名  连接池
     * @return
     */
    public static DruidDataSource getConnRs(String dataName) {

            try {
                DruidDataSource druidDataSource = new DruidDataSource();
                druidDataSource.setUrl("jdbc:mysql://21.12.0.10:3306/"+dataName+"?useUnicode=true&characterEncoding" +
                        "=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8");
                druidDataSource.setUsername("root");
                druidDataSource.setPassword("Bwie-8666");
                druidDataSource.setDriverClassName(new ConnectReq().getDRIVER());

                return druidDataSource;
            } catch (Exception e) {
                log.error("异常为：{}", String.valueOf(e));

        }

        return null;
    }

    /**
     * 查询服务器上说有数据库中表名  连接池
     * @return
     */
    public static DruidDataSource getDataConnRs(String name) {

        try {
            DruidDataSource druidDataSource = new DruidDataSource();
            druidDataSource.setUrl("jdbc:mysql://21.12.0.10:3306/"
                    +name+
                    "?useUnicode=true&characterEncoding=" +
                    "utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8");
            druidDataSource.setUsername("root");
            druidDataSource.setPassword("Bwie-8666");
            druidDataSource.setDriverClassName(new ConnectReq().getDRIVER());

            return druidDataSource;
        } catch (Exception e) {
            log.error("异常为：{}", String.valueOf(e));

        }

        return null;
    }

    public static void close(Connection connection,PreparedStatement preparedStatement,ResultSet resultSet) throws SQLException {

        if (null != connection){
            connection.close();
        }

        if (null != preparedStatement){
            preparedStatement.close();
        }

        if (null != resultSet){
            resultSet.close();
        }
    }
}
